==> igniteui-react-layouts-18.3.0-beta.2.tgz: package/esm5/lib/igr-tool-action-group-header.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionGroupHeader = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionGroupHeader, _super);
    function IgrToolActionGroupHeader(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionGroupHeader.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.fc);
        },
        set: function (v) {
            this.i.fc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.fd);
        },
        set: function (v) {
            this.i.fd = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionGroupHeader;
}(IgrToolAction));
export { IgrToolActionGroupHeader };

==> igniteui-react-layouts-18.7.5-beta.2.tgz: package/esm5/lib/igr-tool-action-group-header.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionGroupHeader = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionGroupHeader, _super);
    function IgrToolActionGroupHeader(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionGroupHeader.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.hg);
        },
        set: function (v) {
            this.i.hg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionGroupHeader.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.hh);
        },
        set: function (v) {
            this.i.hh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionGroupHeader;
}(IgrToolAction));
export { IgrToolActionGroupHeader };
